@@ -1,15 +1,15 @@
 #' Check kobotoolbox API and retrieve overall info about the projects/assets
 #'
-#'@description
+#' @description
 #' `kobotools_api` is a wrapper for kobotoolbox API `https://[kpi-url]/api/v2/assets.json`
 #'
-#'@details
-#' The function takes two variables. First one is `url` which is the `[kpi-url]`. For most users it will be "kobo.humanitarianresponse.info" or
+#' @details
+#' The function takes two variables. First one is `url` which is the `[kpi-url]`. For most users it will be "eu.kobotoolbox.org" or
 #' "kf.kobotoolbox.org". Former is the default. The second parameter is `simplified` which takes a logical value. If set to true,
 #' the function will return selected values from the parsed data and return a data frame. When set to false, a json will be returned with
 #' all the details.
 #'
-#' @param url The `[kpi-url]` of kobotoolbox. Default is "kobo.humanitarianresponse.info"
+#' @param url The `[kpi-url]` of kobotoolbox. Default is "eu.kobotoolbox.org"
 #' @param simplified A logical value, default is true
 #' @param uname takes the username
 #' @param pwd takes the password
@@ -30,77 +30,75 @@
 #'
 #' @export
 
-kobotools_api<- function(url="kobo.humanitarianresponse.info", simplified=TRUE, uname="", pwd="", encoding = "UTF-8") {
+kobotools_api <- function(url = "eu.kobotoolbox.org", simplified = TRUE, uname = "", pwd = "", encoding = "UTF-8") {
+  if (!is.character(url)) stop("URL entered is not a string")
+  if (!is.character(uname)) stop("uname (username) entered is not a string")
+  if (!is.character(pwd)) stop("pwd (password) entered is not a string")
+  if (is.null(url) | url == "") stop("URL empty")
+  if (is.null(uname) | uname == "") stop("uname (username) empty")
+  if (is.null(pwd) | pwd == "") stop("pwd (password) empty")
+  if (!is.logical(simplified)) stop("simplied can take only logical value")
 
-
-  if(!is.character(url)) stop("URL entered is not a string")
-  if(!is.character(uname)) stop("uname (username) entered is not a string")
-  if(!is.character(pwd)) stop("pwd (password) entered is not a string")
-  if(is.null(url) | url=="") stop("URL empty")
-  if(is.null(uname) | uname=="") stop("uname (username) empty")
-  if(is.null(pwd) | pwd =="") stop("pwd (password) empty")
-  if(!is.logical(simplified)) stop("simplied can take only logical value")
-
-  fullurl<-paste0("https://",url,"/api/v2/assets.json")
-  respon.api<- tryCatch(
+  fullurl <- paste0("https://", url, "/api/v2/assets.json")
+  respon.api <- tryCatch(
     expr = {
       GET(fullurl, authenticate(uname, pwd), progress())
     },
-    error = function(x){
+    error = function(x) {
       print("Error. Please try again or check the input parameters.")
       return(NULL)
     }
   )
 
-  if(!is.null(respon.api)){
-    #stop_for_status(respon.api, "extract asset details")
+  if (!is.null(respon.api)) {
+    # stop_for_status(respon.api, "extract asset details")
     parsed <- fromJSON(content(respon.api, "text", encoding = encoding), simplifyVector = FALSE)
 
-    if(simplified==FALSE){
+    if (simplified == FALSE) {
       return(parsed)
     } else {
-      link<-NULL
-      date_created<-NULL
-      date_modified<-NULL
-      owner<-NULL
-      assetid<-NULL
-      name<-NULL
-      active<-NULL
-      submissions<-NULL
-      x<-parsed$count
-      for(i in 1:x){
-        link[i]<-parsed$results[[i]]$url
-        date_created[i]<-parsed$results[[i]]$date_created
-        date_modified[i]<-parsed$results[[i]]$date_modified
-        owner[i]<-parsed$results[[i]]$owner__username
-        assetid[i]<-parsed$results[[i]]$uid
-        name[i]<-parsed$results[[i]]$name
-        active[i]<-parsed$results[[i]]$deployment__active
-        submissions[i]<-parsed$results[[i]]$deployment__submission_count
+      link <- NULL
+      date_created <- NULL
+      date_modified <- NULL
+      owner <- NULL
+      assetid <- NULL
+      name <- NULL
+      active <- NULL
+      submissions <- NULL
+      x <- parsed$count
+      for (i in 1:x) {
+        link[i] <- parsed$results[[i]]$url
+        date_created[i] <- parsed$results[[i]]$date_created
+        date_modified[i] <- parsed$results[[i]]$date_modified
+        owner[i] <- parsed$results[[i]]$owner__username
+        assetid[i] <- parsed$results[[i]]$uid
+        name[i] <- parsed$results[[i]]$name
+        active[i] <- parsed$results[[i]]$deployment__active
+        submissions[i] <- parsed$results[[i]]$deployment__submission_count
       }
-      simp.parsed<- data.frame(name=name, asset=assetid, active=active,submissions=submissions, owner=owner,
-                               date_created=date_created, date_modified=date_modified, URL=link)
+      simp.parsed <- data.frame(
+        name = name, asset = assetid, active = active, submissions = submissions, owner = owner,
+        date_created = date_created, date_modified = date_modified, URL = link
+      )
       return(simp.parsed)
     }
-  } else return(NULL)
-
-
-
-
+  } else {
+    return(NULL)
+  }
 }
 
 
 
 #' Extract data from kobotoolbox
 #'
-#'@description
-#' `kobotools_kpi_data` is a wrapper for kobotoolbox API `https://[URL]/api/v2/assets/{assetid}/data/`
+#' @description
+#' `kobotools_kpi_data` is a wrapper for kobotoolbox API `https://[URL]/api/v2/assets/[assetid]/data/`
 #'
-#'@details
+#' @details
 #' The function takes the url as one of the inputs. And asset id as another. Both are strings. The asset id is found by running
 #' the [kobotools_api()] function.Other parameters are username and password.
 #'
-#' @param url The `[kpi-url]` of kobotoolbox. Default is "kobo.humanitarianresponse.info"
+#' @param url The `[kpi-url]` of kobotoolbox. Default is "eu.kobotoolbox.org"
 #' @param assetid is the asset id of the asset for which the data is to be downloaded. The id can be found by running [kobotools_data_list_kc()]
 #' @param uname is username of your kobotoolbox account
 #' @param pwd is the password of the account
@@ -116,48 +114,46 @@ kobotools_api<- function(url="kobo.humanitarianresponse.info", simplified=TRUE,
 #'
 #' @export
 
-kobotools_kpi_data<- function(assetid,url="kobo.humanitarianresponse.info", uname="", pwd="", encoding = "UTF-8") {
-
-  if(!is.character(url)) stop("URL entered is not a string")
-  if(!is.character(uname)) stop("uname (username) entered is not a string")
-  if(!is.character(pwd)) stop("pwd (password) entered is not a string")
-  if(!is.character(assetid)) stop("assetid entered in not string")
-  if(is.null(url) | url=="") stop("URL empty")
-  if(is.null(uname) | uname=="") stop("uname (username) empty")
-  if(is.null(pwd) | pwd=="") stop("pwd (password) empty")
-  if(is.null(assetid) | assetid=="") stop("assetid empty")
+kobotools_kpi_data <- function(assetid, url = "eu.kobotoolbox.org", uname = "", pwd = "", encoding = "UTF-8") {
+  if (!is.character(url)) stop("URL entered is not a string")
+  if (!is.character(uname)) stop("uname (username) entered is not a string")
+  if (!is.character(pwd)) stop("pwd (password) entered is not a string")
+  if (!is.character(assetid)) stop("assetid entered in not string")
+  if (is.null(url) | url == "") stop("URL empty")
+  if (is.null(uname) | uname == "") stop("uname (username) empty")
+  if (is.null(pwd) | pwd == "") stop("pwd (password) empty")
+  if (is.null(assetid) | assetid == "") stop("assetid empty")
 
 
-  fullurl<-paste0("https://",url,"/api/v2/assets/",assetid,"/data/")
-  respon.kpi<- tryCatch(
+  fullurl <- paste0("https://", url, "/api/v2/assets/", assetid, "/data/")
+  respon.kpi <- tryCatch(
     expr = {
       GET(fullurl, authenticate(uname, pwd), progress())
     },
-    error= function(x){
+    error = function(x) {
       print("Error. Please try again or check the input parameters.")
       return(NULL)
     }
   )
 
-  if(!is.null(respon.kpi)){
+  if (!is.null(respon.kpi)) {
     stop_for_status(respon.kpi, "extract data")
-    dt<-content(respon.kpi, encoding = encoding)
+    dt <- content(respon.kpi, encoding = encoding)
     return(dt)
-  } else return(NULL)
-
-
-
+  } else {
+    return(NULL)
+  }
 }
 
 #' Know your API token or check
 #'
-#'@description
+#' @description
 #' `get_kobo_token` is a wrapper for kobotoolbox API `https://"[url]"/token/?format=json`
 #'
-#'@details
+#' @details
 #' The function returns the API token.
 #'
-#' @param url The `[url]` of kobotoolbox. Default is "kobo.humanitarianresponse.info".
+#' @param url The `[url]` of kobotoolbox. Default is "eu.kobotoolbox.org".
 #' @param uname is username of your kobotoolbox account
 #' @param pwd is the password of the account
 #' @param encoding is the encoding to be used. Default is "UTF-8".
@@ -171,45 +167,44 @@ kobotools_kpi_data<- function(assetid,url="kobo.humanitarianresponse.info", unam
 #'
 #' @export
 
-get_kobo_token <- function(url="kobo.humanitarianresponse.info", uname="", pwd="", encoding = "UTF-8"){
+get_kobo_token <- function(url = "eu.kobotoolbox.org", uname = "", pwd = "", encoding = "UTF-8") {
+  if (!is.character(url)) stop("URL entered is not a string")
+  if (!is.character(uname)) stop("uname (username) entered is not a string")
+  if (!is.character(pwd)) stop("pwd (password) entered is not a string")
+  if (is.null(url) | url == "") stop("URL empty")
+  if (is.null(uname) | uname == "") stop("uname (username) empty")
+  if (is.null(pwd) | pwd == "") stop("pwd (password) empty")
 
-  if(!is.character(url)) stop("URL entered is not a string")
-  if(!is.character(uname)) stop("uname (username) entered is not a string")
-  if(!is.character(pwd)) stop("pwd (password) entered is not a string")
-  if(is.null(url) | url=="") stop("URL empty")
-  if(is.null(uname) | uname=="") stop("uname (username) empty")
-  if(is.null(pwd) | pwd=="") stop("pwd (password) empty")
-
-  fullurl<-paste0("https://",url,"/token/?format=json")
-  respon.token<- tryCatch(
+  fullurl <- paste0("https://", url, "/token/?format=json")
+  respon.token <- tryCatch(
     expr = {
       GET(fullurl, authenticate(uname, pwd), progress())
     },
-    error = function(x){
+    error = function(x) {
       print("Error. Please try again or check the input parameters.")
       return(NULL)
     }
   )
 
-  if(!is.null(respon.token)){
-    #stop_for_status(respon.token,"extract token")
-    tkn<-fromJSON(content(respon.token,"text", encoding = encoding))
+  if (!is.null(respon.token)) {
+    # stop_for_status(respon.token,"extract token")
+    tkn <- fromJSON(content(respon.token, "text", encoding = encoding))
     return(tkn)
-  } else return(NULL)
-
-
+  } else {
+    return(NULL)
+  }
 }
 
 
 #' See list of exports created
 #'
-#'@description
+#' @description
 #' `kobo_exports` is a wrapper for kobotoolbox API `https://[url]/exports/`
 #'
-#'@details
+#' @details
 #' The function returns the export views.
 #'
-#' @param url The `[url]` of kobotoolbox. Default is "kobo.humanitarianresponse.info".
+#' @param url The `[url]` of kobotoolbox. Default is "eu.kobotoolbox.org".
 #' @param uname is username of your kobotoolbox account
 #' @param pwd is the password of the account
 #' @param encoding is the encoding to be used. Default is "UTF-8".
@@ -222,45 +217,44 @@ get_kobo_token <- function(url="kobo.humanitarianresponse.info", uname="", pwd="
 #'
 #' @export
 
-kobo_exports <- function(url="kobo.humanitarianresponse.info", uname="", pwd="", encoding = "UTF-8"){
+kobo_exports <- function(url = "eu.kobotoolbox.org", uname = "", pwd = "", encoding = "UTF-8") {
+  if (!is.character(url)) stop("URL entered is not a string")
+  if (!is.character(uname)) stop("uname (username) entered is not a string")
+  if (!is.character(pwd)) stop("pwd (password) entered is not a string")
+  if (is.null(url)) stop("URL empty")
+  if (is.null(uname)) stop("uname (username) empty")
+  if (is.null(pwd)) stop("pwd (password) empty")
 
-  if(!is.character(url)) stop("URL entered is not a string")
-  if(!is.character(uname)) stop("uname (username) entered is not a string")
-  if(!is.character(pwd)) stop("pwd (password) entered is not a string")
-  if(is.null(url)) stop("URL empty")
-  if(is.null(uname)) stop("uname (username) empty")
-  if(is.null(pwd)) stop("pwd (password) empty")
-
-  fullurl<-paste0("https://",url,"/exports/")
-  respon.exp<- tryCatch(
+  fullurl <- paste0("https://", url, "/exports/")
+  respon.exp <- tryCatch(
     expr = {
       GET(fullurl, authenticate(uname, pwd), progress())
     },
-    error = function(x){
+    error = function(x) {
       print("Error. Please try again or check the input parameters.")
-      return (NULL)
+      return(NULL)
     }
   )
 
-  if(!is.null(respon.exp)){
-    stop_for_status(respon.exp,"extract export list.")
-    exports<-fromJSON(content(respon.exp,"text", encoding = encoding))
+  if (!is.null(respon.exp)) {
+    stop_for_status(respon.exp, "extract export list.")
+    exports <- fromJSON(content(respon.exp, "text", encoding = encoding))
     return(exports)
-  } else return (NULL)
-
-
+  } else {
+    return(NULL)
+  }
 }
 
 
 #' Create an export
 #'
-#'@description
+#' @description
 #' `kobo_export_create` is a wrapper for kobotoolbox API `https://[url]/exports/..`
 #'
-#'@details
+#' @details
 #' The function creates an export of survey data. If successful, returns the URL of the data that can be directly downloaded/read/imported in R.
 #'
-#' @param url The `[url]` of kobotoolbox Default is "kobo.humanitarianresponse.info".
+#' @param url The `[url]` of kobotoolbox Default is "eu.kobotoolbox.org".
 #' @param uname is username of your kobotoolbox account
 #' @param pwd is the password of the account
 #' @param assetid is the id of the asset for which the export is to be created
@@ -293,37 +287,37 @@ kobo_exports <- function(url="kobo.humanitarianresponse.info", uname="", pwd="",
 #' @export
 
 
-kobo_export_create <- function(url="kobo.humanitarianresponse.info", uname="", pwd="",
-                               assetid="", type= "csv", all="false", lang="_default",
-                               hierarchy="false", include_grp="true",grp_sep="/",
-                               multi_sel="both", fields=NULL, media_url ="true",
-                               sub_ids=NULL, qry=NULL, flatten="true", sleep=2){
-
-  export_res<-export_creator(url=url, uname=uname, pwd=pwd,
-                 assetid=assetid, type= type, all=all, lang=lang,
-                 hierarchy=hierarchy, include_grp=include_grp,grp_sep=grp_sep,
-                 multi_sel=multi_sel, fields=fields, media_url=media_url,
-                 sub_ids=sub_ids, qry=qry, flatten=flatten, sleep=sleep)
-  if(is.null(export_res)){
+kobo_export_create <- function(url = "eu.kobotoolbox.org", uname = "", pwd = "",
+                               assetid = "", type = "csv", all = "false", lang = "_default",
+                               hierarchy = "false", include_grp = "true", grp_sep = "/",
+                               multi_sel = "both", fields = NULL, media_url = "true",
+                               sub_ids = NULL, qry = NULL, flatten = "true", sleep = 2) {
+  export_res <- export_creator(
+    url = url, uname = uname, pwd = pwd,
+    assetid = assetid, type = type, all = all, lang = lang,
+    hierarchy = hierarchy, include_grp = include_grp, grp_sep = grp_sep,
+    multi_sel = multi_sel, fields = fields, media_url = media_url,
+    sub_ids = sub_ids, qry = qry, flatten = flatten, sleep = sleep
+  )
+  if (is.null(export_res)) {
     print("Export Could Not be created")
     return(NULL)
-  } else{
+  } else {
     print(export_res[1])
     return(unlist(export_res[1]))
   }
-
 }
 
 
 #' Creates a data frame after creating a 'csv' export and downloading it
 #'
-#'@description
+#' @description
 #' `kobo_df_download` is a wrapper for kobotoolbox API `https://[url]/exports/..`
 #'
-#'@details
+#' @details
 #' The function creates an export of survey data in 'csv'. If successful, it attempts to download the data and and return a data frame.
 #'
-#' @param url The `[url]` of kobotoolbox Default is "kobo.humanitarianresponse.info".
+#' @param url The `[url]` of kobotoolbox Default is "eu.kobotoolbox.org".
 #' @param uname is username of your kobotoolbox account
 #' @param pwd is the password of the account
 #' @param assetid is the id of the asset for which the export is to be created
@@ -354,47 +348,48 @@ kobo_export_create <- function(url="kobo.humanitarianresponse.info", uname="", p
 #' @export
 
 
-kobo_df_download <- function(url="kobo.humanitarianresponse.info", uname="", pwd="",
-                               assetid="", all="false", lang="_default",
-                               hierarchy="false", include_grp="true",grp_sep="/",fsep=";",
-                              multi_sel="both", media_url="true", fields=NULL, sub_ids=NULL, sleep=2){
-
-  new_export_details<-export_creator(url=url, uname=uname, pwd=pwd,
-                                                 assetid=assetid, type= "csv", all=all, lang=lang,
-                                                 hierarchy=hierarchy, include_grp=include_grp,grp_sep=grp_sep,
-                                     multi_sel=multi_sel, fields=fields, media_url=media_url, sub_ids=sub_ids, sleep=sleep)
+kobo_df_download <- function(url = "eu.kobotoolbox.org", uname = "", pwd = "",
+                             assetid = "", all = "false", lang = "_default",
+                             hierarchy = "false", include_grp = "true", grp_sep = "/", fsep = ";",
+                             multi_sel = "both", media_url = "true", fields = NULL, sub_ids = NULL, sleep = 2) {
+  new_export_details <- export_creator(
+    url = url, uname = uname, pwd = pwd,
+    assetid = assetid, type = "csv", all = all, lang = lang,
+    hierarchy = hierarchy, include_grp = include_grp, grp_sep = grp_sep,
+    multi_sel = multi_sel, fields = fields, media_url = media_url, sub_ids = sub_ids, sleep = sleep
+  )
 
   Sys.sleep(sleep)
 
-  if(is.null(new_export_details)){
+  if (is.null(new_export_details)) {
     print("export creation was not successful")
     return(NULL)
-  } else{
-    dff<-export_downloader(new_export_details[[1]],fsep, uname, pwd, sleep)
+  } else {
+    dff <- export_downloader(new_export_details[[1]], fsep, uname, pwd, sleep)
 
-    deleteact<-DELETE(url=paste0(url,"/api/v2/assets/",assetid,"/exports/",new_export_details[[2]],"/"),
-                      authenticate(user=uname, password =pwd), progress())
-    while(is.na(deleteact$status_code) | is.null(deleteact$status_code)){
+    deleteact <- DELETE(
+      url = paste0(url, "/api/v2/assets/", assetid, "/exports/", new_export_details[[2]], "/"),
+      authenticate(user = uname, password = pwd), progress()
+    )
+    while (is.na(deleteact$status_code) | is.null(deleteact$status_code)) {
       print("Attempting export deletion \n")
     }
-    warn_for_status(deleteact,"delete export. Please delete manually.")
-    if(deleteact$status_code==204) print("Export deleted from server")
+    warn_for_status(deleteact, "delete export. Please delete manually.")
+    if (deleteact$status_code == 204) print("Export deleted from server")
     return(dff)
   }
-
-
 }
 
 
 #'  Downloads media data from Kobotoolbox
 #'
-#'@description
+#' @description
 #' `kobo_media_downloader` downloads media from data downloaded using `kobo_df_download`. Loops through media columns and downloads files individually.`
 #'
-#'@details
+#' @details
 #' The function creates an export of survey data in 'csv'. If successful, it attempts to download the data and and return a data frame.
 #'
-#' @param url The `[url]` of kobotoolbox Default is "kobo.humanitarianresponse.info".
+#' @param url The `[url]` of kobotoolbox Default is "eu.kobotoolbox.org".
 #' @param uname is username of your kobotoolbox account
 #' @param pwd is the password of the account
 #' @param assetid is the id of the asset for which the export is to be created
@@ -414,26 +409,28 @@ kobo_df_download <- function(url="kobo.humanitarianresponse.info", uname="", pwd
 #'
 #' @export
 
-kobo_media_downloader <- function(url="kobo.humanitarianresponse.info",uname,pwd, assetid, fsep=";", sleep=2, identifier="URL", timeoutval=300, destfolder="media"){
-  dat<-kobo_df_download(url=url,uname = uname,
-                   pwd=pwd, assetid = assetid,
-                   lang = "_default", sleep=sleep, fsep=fsep)
-  if(!is.null(dat)){
+kobo_media_downloader <- function(url = "eu.kobotoolbox.org", uname, pwd, assetid, fsep = ";", sleep = 2, identifier = "URL", timeoutval = 300, destfolder = "media") {
+  dat <- kobo_df_download(
+    url = url, uname = uname,
+    pwd = pwd, assetid = assetid,
+    lang = "_default", sleep = sleep, fsep = fsep
+  )
+  if (!is.null(dat)) {
     print("Please note that this function loops over the URLs and downloads the individual files. This process can be slow and
         some files may fail to download due to timeout issues. Downloading a zipped file is not supported using API, yet in Kobotoolbox.")
 
-    cnamesdat<-colnames(dat)
+    cnamesdat <- colnames(dat)
 
-    urlcols<-cnamesdat[grepl(paste0("*",identifier),cnamesdat)]
+    urlcols <- cnamesdat[grepl(paste0("*", identifier), cnamesdat)]
     options(timeout = max(timeoutval, getOption("timeout")))
 
-    if (!file.exists(destfolder)){
+    if (!file.exists(destfolder)) {
       dir.create(destfolder)
     }
 
-    for(i in 1:length(urlcols)){
-      fname<-paste0("./",destfolder,"/",urlcols[i],"_",seq(1:length(dat[,urlcols[i]])))
-      download.file(dat[,urlcols[i]],fname, method="libcurl")
+    for (i in 1:length(urlcols)) {
+      fname <- paste0("./", destfolder, "/", urlcols[i], "_", seq(1:length(dat[, urlcols[i]])))
+      download.file(dat[, urlcols[i]], fname, method = "libcurl")
     }
 
     return(TRUE)
@@ -441,20 +438,17 @@ kobo_media_downloader <- function(url="kobo.humanitarianresponse.info",uname,pwd
     print("Data could not be downloaded. Please try again or check the parameters.")
     return(FALSE)
   }
-
-
-
 }
 
 #'  Downloads data (xls type) from Kobotoolbox
 #'
-#'@description
+#' @description
 #' `kobo_xls_dl` is a wrapper for kobotoolbox API `https://[url]/exports/..`
 #'
-#'@details
+#' @details
 #' The function creates an export of survey data in 'xls'. If successful, it attempts to download the data and and return a data frame (reading using `readxl::read_excel`).
 #'
-#' @param url The `[url]` of kobotoolbox Default is "kobo.humanitarianresponse.info".
+#' @param url The `[url]` of kobotoolbox Default is "eu.kobotoolbox.org".
 #' @param uname is username of your kobotoolbox account
 #' @param pwd is the password of the account
 #' @param assetid is the id of the asset for which the export is to be created
@@ -484,33 +478,33 @@ kobo_media_downloader <- function(url="kobo.humanitarianresponse.info",uname,pwd
 #' @importFrom purrr map
 #'
 #' @export
-kobo_xls_dl<- function(url="kobo.humanitarianresponse.info", uname="", pwd="",
-                       assetid="", all="false", lang="_default",
-                       hierarchy="false", include_grp="true",grp_sep="/",
-                       multi_sel="both", media_url="true", fields=NULL, sub_ids=NULL, sleep=2){
-
-  new_export_details<-export_creator(url=url, uname=uname, pwd=pwd,
-                                     assetid=assetid, type= "xls", all=all, lang=lang,
-                                     hierarchy=hierarchy, include_grp=include_grp,grp_sep=grp_sep,
-                                     multi_sel=multi_sel, fields=fields, media_url=media_url, sub_ids=sub_ids, sleep=sleep)
+kobo_xls_dl <- function(url = "eu.kobotoolbox.org", uname = "", pwd = "",
+                        assetid = "", all = "false", lang = "_default",
+                        hierarchy = "false", include_grp = "true", grp_sep = "/",
+                        multi_sel = "both", media_url = "true", fields = NULL, sub_ids = NULL, sleep = 2) {
+  new_export_details <- export_creator(
+    url = url, uname = uname, pwd = pwd,
+    assetid = assetid, type = "xls", all = all, lang = lang,
+    hierarchy = hierarchy, include_grp = include_grp, grp_sep = grp_sep,
+    multi_sel = multi_sel, fields = fields, media_url = media_url, sub_ids = sub_ids, sleep = sleep
+  )
 
   Sys.sleep(sleep)
 
-  if(is.null(new_export_details)){
+  if (is.null(new_export_details)) {
     print("export creation was not successful")
     return(NULL)
-  } else{
-    dff<-export_downloader(new_export_details[[1]], uname=uname, pwd=pwd, sleep=sleep, type="xls")
-    deleteact<-DELETE(url=paste0(url,"/api/v2/assets/",assetid,"/exports/",new_export_details[[2]],"/"),
-                      authenticate(user=uname, password = pwd), progress())
-    while(is.na(deleteact$status_code) | is.null(deleteact$status_code)){
+  } else {
+    dff <- export_downloader(new_export_details[[1]], uname = uname, pwd = pwd, sleep = sleep, type = "xls")
+    deleteact <- DELETE(
+      url = paste0(url, "/api/v2/assets/", assetid, "/exports/", new_export_details[[2]], "/"),
+      authenticate(user = uname, password = pwd), progress()
+    )
+    while (is.na(deleteact$status_code) | is.null(deleteact$status_code)) {
       print("Attempting export deletion \n")
     }
-    warn_for_status(deleteact,"delete export. Please delete manually.")
-    if(deleteact$status_code==204) print("Export deleted from server")
+    warn_for_status(deleteact, "delete export. Please delete manually.")
+    if (deleteact$status_code == 204) print("Export deleted from server")
     return(dff)
   }
-
-
 }
-
